"""Gives users direct access to class and functions."""
from logical.logical import\
    logical,\
    nullary, unary, binary, every,\
    nf_, nt_,\
    uf_, id_, not_, ut_,\
    bf_,\
    and_, nimp_, fst_, nif_, snd_, xor_, or_,\
    nor_, xnor_, nsnd_, if_, nfst_, imp_, nand_,\
    bt_
